pub struct Inertia {
pub diag_inertia: Vec3,
pub inertia_rotation: Option<UnitQuat>,
pub center_of_mass: Option<Vec3>,
}Expand description
The inertia properties of a shape.
Fields
diag_inertia: Vec3The mass normalized diagonal inerita with principal axis pass through the center of mass.
inertia_rotation: Option<UnitQuat>The rotation from principal axis space to shape space. None if no rotation is needed.
center_of_mass: Option<Vec3>The center of mass in shape space. None if the center of mass is at the origin.
Implementations